@@ -1,4 +1,4 @@
-__version__ = "0.0.1"
+__version__ = "1.2.0"
 
 import logging
 
@@ -37,6 +37,8 @@ class QRonosClient(object):
             'tracker_import': f"{prefix}/tracker_import/",
             'stage_import': f"{prefix}/stage_import/",
             'delete_items': f"{prefix}/delete_items/",
+            'get_attributes': f"{prefix}/attributes/",
+            'get_stages': f"{prefix}/stages/",
         }
 
     def _get(self, *args, **kwargs):
@@ -99,14 +101,14 @@ class QRonosClient(object):
                 raise QRonosError("Unable to get Job ID from Import request") from err
         raise QRonosError(f"Bad Import request - {response.content}")
 
-    def tracker_import(self, tracker_id, tracker_importer_id, unique_columns, data):
+    def tracker_import(self, tracker_id, unique_columns, can_add_item, can_delete_item, data):
         """
         Imports tracker (item) data.
-        Please ensure you know the settings of the tracker importer in QRonos before sending any data.
 
         :param tracker_id: The ID of the Tracker
-        :param tracker_importer_id: The ID of the Tracker Importer
         :param unique_columns: A list of the header fields
+        :param can_add_item: Import can add Items?
+        :param can_delete_item: Import can delete Items?
         :param data: The import data as a list of dictionaries (keys must match the headers from unique_columns parameter)
         :return: Job ID
         """
@@ -114,38 +116,34 @@ class QRonosClient(object):
             self.urls['tracker_import'],
             {
                 'tracker': tracker_id,
-                'tracker_importer': tracker_importer_id,
                 'unique_columns': unique_columns,
-                'data': data
+                'can_add_item': can_add_item,
+                'can_delete_item': can_delete_item,
+                'data': data,
             }
         )
 
-    def stage_import(self, stage_id, stage_importer_id, data):
+    def stage_import(self, stage_id, data):
         """
         Imports stage data.
-        Please ensure you know the settings of the stage importer in QRonos before sending any data.
 
         :param stage_id: The ID of the Stage
-        :param stage_importer_id: The ID of the Stage Importer
-        :param data: The import data as a list of dictionaries (keys must match headers set up in QRonos)
+        :param data: The import data as a list of dictionaries (keys must match names in QRonos)
         :return: Job ID
         """
         return self._run_import(
             self.urls['stage_import'],
             {
                 'stage': stage_id,
-                'stage_importer': stage_importer_id,
-                'data': data
+                'data': data,
             }
         )
 
-    def delete_items(self, tracker_id, tracker_importer_id, data):
+    def delete_items(self, tracker_id, data):
         """
         Deletes Items from a Tracker
-        Please ensure you know the settings of the tracker importer in QRonos before sending any data.
 
         :param tracker_id: The ID of the Tracker
-        :param tracker_importer_id: The ID of the Tracker Importer
         :param data: A list of the unique keys you wish to delete
         :return: Job ID
         """
@@ -153,7 +151,75 @@ class QRonosClient(object):
             self.urls['delete_items'],
             {
                 'tracker': tracker_id,
-                'tracker_importer': tracker_importer_id,
                 'data': data
             }
         )
+
+    def get_item_attributes(self, show_mastered=True, show_non_mastered=True, tracker=None, unique_keys=None, unique_key=None):
+        """
+        Get item attributes with a tracker ID or using a unique key(s)
+
+        Keyword arguments:
+            :param show_mastered: Include mastered attributes
+            :param show_non_mastered: Include non-mastered attributes
+            :param tracker: The ID of the Tracker
+            :param unique_keys: A list of unique item keys
+            :param unique_key: A unique item key 
+        :return: Item attributes
+        """
+
+        post_data = {
+            "show_mastered": show_mastered,
+            "show_non_mastered": show_non_mastered,
+        }
+
+        if tracker:
+            post_data["tracker"] = tracker
+        if unique_keys:
+            post_data["unique_keys"] = unique_keys
+        elif unique_key:
+            post_data["unique_key"] = unique_key
+
+        response = self._post(self.urls['get_attributes'], json=post_data)
+        if response.status_code == 200:
+            try:
+                return response.json()["items"]
+            except Exception as err:
+                raise QRonosError("Unable to get attribute data") from err
+        elif response.status_code == 400:
+            raise QRonosError(f"Bad Request - {response.json()}")
+
+    def get_item_stages(self, tracker=None, unique_keys=None, unique_key=None, stages=None, stage=None):
+        """
+        Get item stages with a tracker ID or using a unique key(s) which can be restricted by stage(s)
+
+        Keyword arguments:
+            :param tracker: The ID of the Tracker
+            :param unique_keys: A list of unique item keys
+            :param unique_key: A unique item key
+            :param stages: A list of stage ids
+            :param stage: The ID of a stage (TrackerStage model)
+        :return: Item stages
+        """
+
+        post_data = {}
+
+        if tracker:
+            post_data["tracker"] = tracker
+        if unique_keys:
+            post_data["unique_keys"] = unique_keys
+        elif unique_key:
+            post_data["unique_key"] = unique_key
+        if stages:
+            post_data["stages"] = stages
+        elif stage:
+            post_data["stage"] = stage
+
+        response = self._post(self.urls['get_stages'], json=post_data)
+        if response.status_code == 200:
+            try:
+                return response.json()["items"]
+            except Exception as err:
+                raise QRonosError("Unable to get stage data") from err
+        elif response.status_code == 400:
+            raise QRonosError(f"Bad Request - {response.json()}")
